cd "C:\Users\Luisa\Desktop\Datasets\CRONOS"
use "CRONOS_ESS8_e01_2.dta", clear

/*
-------- Cleaning the dataset: rename/recode variables + drop missing cases --------                                                                         */

*Gender
tab gndr, miss

*Age
tab agea
recode agea (18/29=1 "18-29") (30/49=2 "30-49")(50/100=3 "50+") (else=.), gen(age)
tab age, miss

*Legal Union 
tab maritalb
recode maritalb (4/6=0 "No") (1/2=1 "Yes") (else=.), gen(lunion)
tab lunion

*Children 
tab chldhm, miss // Children living at home or not
tab chldhhe, miss // Ever had children living in household
tab chldhm chldhhe, miss

generate havechld=.
replace havechld=1 if chldhm==1 
replace havechld=2 if chldhm==2 
replace havechld=1 if chldhhe==1
replace havechld=. if missing(chldhhe) & havechld==2
tab havechld, miss

label define NoYes_lab 	///
2 "No"					///
1 "Yes"
label values havechld NoYes_lab 
tab havechld, miss

*Edu level
tab edulvlb
recode edulvlb (0/222=1 "Low") (229/423=2 "Medium") (510/800=3 "High") (else=.), gen(edul)
tab edul

*Country
tab cntry
tab cntry, nola
encode cntry, gen(country)
tab country, nola
tab country, miss

*----------------------------------------------------------------------------------------------------------------------

*18 items on intesive parenting*
alpha w2q55 w2q56 w2q57 w2q58 w2q59 w2q60 w2q61 w2q62 w2q63 w2q64 w2q65 w2q66 w2q67 w2q68 w2q69 w2q70 w2q71 w2q72, item

*ssc install fre // FRE: Stata module to display one-way frequency table

*Child-centerd parenting
fre w2q55 // Children’s needs should come before those of their parents
fre w2q59 // A family’s daily routine should be organised around what works best for parents rather than for their children
fre w2q63 // Children should be the centre of their parents’ attention
fre w2q70 // Parents have a life of their own and should not be asked to sacrifice their own well-being for the sake of their children
fre w2q67 // It is a parents’ role to discover and develop their children’s special talents

*Expert-guided parenting
fre w2q56 // It’s best that parents listen to the parenting advice of professionals rather than simply rely on family and friends 
fre w2q60 // Parents who seek advice on parenting are admitting that they are not doing a very good job
fre w2q64 // Parents naturally know how best to bring up their children
fre w2q68 // Good parents should be aware of what experts say and write about the development of children

*Resource-intensive parenting
fre w2q57 // It is alright for parents to, now and then, be less available for their children
fre w2q61 // Parents should always be available for their children
fre w2q65 // To reach their full potential, it is important that children take part in a wide range of organised activities outside of their home
fre w2q69 // Parents should make sure their children’s basic needs are met, even if it means cutting down on essentials for themselves
fre w2q71 // Good parents are those who buy their children the latest toys and gadgets

*Emotionally absorbing parenting
fre w2q58 // A child’s successes and failures mostly reflect how well their parents are bringing them up
fre w2q62 // Parents need to give children the freedom to learn from their own mistakes
fre w2q66 // Good parents constantly worry about their child’s well-being and comfort
fre w2q72 // Parenting is very stressful if you want to do it right

*Rename/Recode items 

/* 
NB= In order to make sure that a high score on the item means a high support on intensive parenting, 
11 items on 18 were reversed coded to capture the opposite of intensive parenting. 
Original response scale: 1 strongly agree - 5 strongly disagree. 
*/

recode w2q55 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(ChNeeds)
recode w2q56 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(AdviceProf)
rename w2q57 LessAvailable
recode w2q58 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(ChSuccess)
rename w2q59 FamRoutine
rename w2q60 BadJob
recode w2q61 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(AlwaysAvailable)
rename w2q62 ChMistakes
recode w2q63 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(ChAttention)
rename w2q64 PaKnow
recode w2q65 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(Activities)
recode w2q66 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(PaWorry)
recode w2q67 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(ChTalents)
recode w2q68 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(AwareExperts)
recode w2q69 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(BasicNeeds)
rename w2q70 PaLife
rename w2q71 LatestToys
recode w2q72 (5 = 1 "Strongly disagree") (4=2 "Disagree") (3 =3 "Neither agree nor disagree") (2 = 4 "Agree") (1=5 "Strongly agree") (else=.), gen(PaStress)

fre ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ChAttention PaKnow Activities PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress
alpha ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ChAttention PaKnow Activities PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress, item

*----------------------------------------------------------------------------------------------------------------------
mdesc /// 
gndr ///
age ///
lunion ///
havechld ///
edul ///
country ///
ChNeeds ///
AdviceProf ///
LessAvailable ///
ChSuccess ///
FamRoutine ///
BadJob ///
AlwaysAvailable ///
ChMistakes ///
ChAttention ///
PaKnow ///
Activities ///
PaWorry ///
ChTalents ///
AwareExperts ///
BasicNeeds ///
PaLife ///
LatestToys ///
PaStress


*Drop missing case
drop if age==.
drop if lunion==.
drop if havechld==.
drop if edul==.

drop if ChNeeds==.
drop if AdviceProf==.
drop if LessAvailable==.
drop if ChSuccess==.
drop if FamRoutine==.
drop if BadJob==.
drop if AlwaysAvailable==.
drop if ChMistakes==.
drop if ChAttention==.
drop if PaKnow==.
drop if Activities==.
drop if PaWorry==.
drop if ChTalents==.
drop if AwareExperts==.
drop if BasicNeeds==.
drop if PaLife==.
drop if LatestToys==.
drop if PaStress==.


keep w2weight gndr age lunion havechld edul country ChNeeds AdviceProf LessAvailable ChSuccess ///
FamRoutine BadJob AlwaysAvailable ChMistakes ChAttention PaKnow Activities PaWorry ChTalents ///
AwareExperts BasicNeeds PaLife LatestToys PaStress ///

fre ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ChAttention PaKnow Activities PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress

save "CRONOS_dataset2020", replace

