use "CRONOS_dataset2020", clear

/* 

0. Descriptive statistics (table 1)  --> line 28

1. FIRST STEP: 
a. Exploratory Factor Analysis (Polychoric) - Pooled data, 18 items --> line 60
b. Exploratory Factor Analysis (Polychoric) - Pooled data, 14 items (table 3) --> line 102
c. Ordinal alpha --> line 113

2. SECOND STEP: 
- Computation of the scales scores --> line 283

3. THIRD STEP:
- OLS regression using the scales as dependent variable (table 5) --> line 331

4. SUPPLEMENTARY ANALYSES:
a. Exploratory Factor Analysis (Polychoric) - 14 items, by country --> line 348
b. Exploratory Factor Analysis (Polychoric) - 18 items, by country --> line 376
c. Mean values and percent agreeing with each item by country + ANOVA --> line 482
d. Mean value of the items for each educational level --> line 638
e. Subscale mean values by country --> line 651
                                                                         
*----------------------------------------------------------------------------------------------------------------------------------*/

** 0. Descriptive statistics (table 1)

*Gender
tab gndr if country==2 [aw=w2weight]  // UK
tab gndr if country==1 [aw=w2weight]  // EE
tab gndr if country==3  [aw=w2weight] // SI

*Age
tab age if country==2 [aw=w2weight]
tab age if country==1 [aw=w2weight]
tab age if country==3 [aw=w2weight]

*Legal Union
tab lunion if country==2 [aw=w2weight]
tab lunion if country==1 [aw=w2weight]
tab lunion if country==3 [aw=w2weight]

*Have Children
tab havechld if country==2 [aw=w2weight]
tab havechld if country==1 [aw=w2weight]
tab havechld if country==3 [aw=w2weight]

*Edu Level
tab edul  if country==2 [aw=w2weight]
tab edul  if country==1 [aw=w2weight]
tab edul  if country==3 [aw=w2weight]

*Country
tab country [aw=w2weight]

*----------------------------------------------------------------------------------------------------------------------------------*

** 1. FIRST STEP: a. Exploratory Factor Analysis (Polychoric) - Pooled data, 18 items 

/* Why polychoric?
Standard methods of performing factor analysis (i.e., those based on a matrix of Pearson’s correlations) 
assume that the variables are continuous and follow a multivariate normal distribution. If the model 
includes variables that are dichotomous or ordinal a factor analysis can be performed using a polychoric 
correlation matrix.*/

**Pooled data**
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] 
display r(sum_w)               // number of cases (with listwise deletion) used to generate the matrix
matrix r = r(R)                // to store the polychoric correlation matrix
factormat r, pcf n(1684)       // run the factor analysis on this correlation matrix
rotate

screeplot

*Eigenvalues>1 - Varimax Rotation
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] 
display r(sum_w)               // number of cases (with listwise deletion) used to generate the matrix
matrix r = r(R)                // to store the polychoric correlation matrix
factormat r, n(1684) pcf factor(6)
rotate 

*Scatterplot - Varimax Rotation (5 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] 
display r(sum_w)               
matrix r = r(R)                  
factormat r, n(1684) pcf factor(5)
rotate 

*Scatterplot - Varimax Rotation (4 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] 
display r(sum_w)               
matrix r = r(R)                
factormat r, n(1684) pcf factor(4)
rotate                            

** 1. FIRST STEP: b. Exploratory Factor Analysis (Polychoric) - Pooled data, 14 items (table 3)
                                                                          
polychoric ChNeeds AdviceProf LessAvailable BadJob AlwaysAvailable ChAttention ///
PaKnow Activities PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys [pw=w2weight] // 14 items
display r(sum_w) // number of cases (with listwise deletion) used to generate the matrix
matrix r = r(R) //  store the polychoric correlation matrix
factormat r, n(1684) 
screeplot
factormat r, n(1684) pcf factor(4)
rotate 

** 1. FIRST STEP: c. Ordinal alpha - Pooled data

*14 Items
polychoric ChNeeds AdviceProf LessAvailable BadJob AlwaysAvailable ChAttention ///
PaKnow Activities PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys [pw=w2weight] 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(4)
rotate 

tempname L Psi
matrix define `L' = e(L)
matrix define `Psi' = e(Psi)

local p = rowsof(`L')

tempname f f2 u2
scalar define `f' = 0
scalar define `f2' = 0
scalar define `u2' = 0
forvalues i = 1/`p' {
scalar define `f' = `f' + `L'[`i', 1]
scalar define `f2' = `f2' + `L'[`i', 1] * `L'[`i', 1]
scalar define `u2' = `u2' + `Psi'[1, `i']
}
scalar define `f' = `f' / `p'
scalar define `f2' = `f2' / `p'
scalar define `u2' = `u2' / `p'

tempname pf2
scalar define `pf2' = `p' * `f' * `f'
scalar define alpha = `p' / (`p' - 1) * ///
(`pf2' - `f2') / (`pf2' + `u2')

display in smcl as text "Ordinal alpha = " as result %06.4f alpha

*Child-intensive
polychoric ChNeeds LessAvailable AlwaysAvailable ChAttention BasicNeeds PaLife [pw=w2weight] 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(1)
rotate 

tempname L Psi
matrix define `L' = e(L)
matrix define `Psi' = e(Psi)

local p = rowsof(`L')

tempname f f2 u2
scalar define `f' = 0
scalar define `f2' = 0
scalar define `u2' = 0
forvalues i = 1/`p' {
scalar define `f' = `f' + `L'[`i', 1]
scalar define `f2' = `f2' + `L'[`i', 1] * `L'[`i', 1]
scalar define `u2' = `u2' + `Psi'[1, `i']
}
scalar define `f' = `f' / `p'
scalar define `f2' = `f2' / `p'
scalar define `u2' = `u2' / `p'

tempname pf2
scalar define `pf2' = `p' * `f' * `f'
scalar define alpha = `p' / (`p' - 1) * ///
(`pf2' - `f2') / (`pf2' + `u2')

display in smcl as text "Ordinal alpha = " as result %06.4f alpha

*Stimulation
polychoric Activities PaWorry ChTalents [pw=w2weight] 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(1)
rotate 

tempname L Psi
matrix define `L' = e(L)
matrix define `Psi' = e(Psi)

local p = rowsof(`L')

tempname f f2 u2
scalar define `f' = 0
scalar define `f2' = 0
scalar define `u2' = 0
forvalues i = 1/`p' {
scalar define `f' = `f' + `L'[`i', 1]
scalar define `f2' = `f2' + `L'[`i', 1] * `L'[`i', 1]
scalar define `u2' = `u2' + `Psi'[1, `i']
}
scalar define `f' = `f' / `p'
scalar define `f2' = `f2' / `p'
scalar define `u2' = `u2' / `p'

tempname pf2
scalar define `pf2' = `p' * `f' * `f'
scalar define alpha = `p' / (`p' - 1) * ///
(`pf2' - `f2') / (`pf2' + `u2')

display in smcl as text "Ordinal alpha = " as result %06.4f alpha

*Responsibility 
polychoric BadJob PaKnow LatestToys [pw=w2weight] 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(1)
rotate 

tempname L Psi
matrix define `L' = e(L)
matrix define `Psi' = e(Psi)

local p = rowsof(`L')

tempname f f2 u2
scalar define `f' = 0
scalar define `f2' = 0
scalar define `u2' = 0
forvalues i = 1/`p' {
scalar define `f' = `f' + `L'[`i', 1]
scalar define `f2' = `f2' + `L'[`i', 1] * `L'[`i', 1]
scalar define `u2' = `u2' + `Psi'[1, `i']
}
scalar define `f' = `f' / `p'
scalar define `f2' = `f2' / `p'
scalar define `u2' = `u2' / `p'

tempname pf2
scalar define `pf2' = `p' * `f' * `f'
scalar define alpha = `p' / (`p' - 1) * ///
(`pf2' - `f2') / (`pf2' + `u2')

display in smcl as text "Ordinal alpha = " as result %06.4f alpha

*Expert-guided
polychoric AdviceProf AwareExperts [pw=w2weight] 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(1)
rotate 

tempname L Psi
matrix define `L' = e(L)
matrix define `Psi' = e(Psi)

local p = rowsof(`L')

tempname f f2 u2
scalar define `f' = 0
scalar define `f2' = 0
scalar define `u2' = 0
forvalues i = 1/`p' {
scalar define `f' = `f' + `L'[`i', 1]
scalar define `f2' = `f2' + `L'[`i', 1] * `L'[`i', 1]
scalar define `u2' = `u2' + `Psi'[1, `i']
}
scalar define `f' = `f' / `p'
scalar define `f2' = `f2' / `p'
scalar define `u2' = `u2' / `p'

tempname pf2
scalar define `pf2' = `p' * `f' * `f'
scalar define alpha = `p' / (`p' - 1) * ///
(`pf2' - `f2') / (`pf2' + `u2')

display in smcl as text "Ordinal alpha = " as result %06.4f alpha

*-------------------------------------------------------------------------------------------------------------------------*

** 2. SECOND STEP: Computation of the scales scores

*Child intensive
egen ipa1=rowmean(ChNeeds LessAvailable AlwaysAvailable ChAttention BasicNeeds PaLife)

polychoric ChNeeds LessAvailable AlwaysAvailable ChAttention BasicNeeds PaLife [pw=w2weight] 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(1)
rotate 

predict ipa_childint

*Stimulation
egen ipa2=rowmean(Activities PaWorry ChTalents)

polychoric Activities PaWorry ChTalents [pw=w2weight] 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(1)
rotate 

predict ipa_stimulation

*Parental Responsibility 
egen ipa3=rowmean(BadJob LatestToys PaKnow)

polychoric BadJob PaKnow LatestToys [pw=w2weight] 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(1)
rotate 

predict ipa_parentresp

*Expert-guidance
egen ipa4=rowmean(AdviceProf AwareExperts)

polychoric AdviceProf AwareExperts [pw=w2weight]   
display r(sum_w) 
matrix r = r(R) 
factormat r, n(1684) pcf factor(1)
rotate 

predict ipa_expert

*----------------------------------------------------------------------------------------------------------------------------------*

** 3. THIRD STEP: OLS regression using the scales as dependent variable (table 5)

eststo clear 

eststo: reg ipa_childint ib2.country i.age i.gndr i.edul i.havechld [pw=w2weight]  // Child intensive scale
eststo: reg ipa_stimulation ib2.country i.age i.gndr i.edul i.havechld [pw=w2weight]  // Stimulation scale
eststo: reg ipa_parentresp ib2.country i.age i.gndr i.edul i.havechld [pw=w2weight]  // Parental Responsibility scale
eststo: reg ipa_expert ib2.country i.age i.gndr i.edul  i.havechld [pw=w2weight]  // Expert-guidance scale

esttab using "C:\Users\Luisa\Desktop\CRONOS_2020\ConvergentValidity_CRONOS2020.txt", /// 
tab replace plain star(+ 0.10 * 0.05 ** 0.01 *** 0.001) b(2) se(2) wide not notes 	///
label constant obslast  aic bic sca(r2 N)

*----------------------------------------------------------------------------------------------------------------------------------*

** 4. SUPPLEMENTARY ANALYSIS:

* a. Exploratory Factor Analysis (Polychoric) - 14 items, by country

*Great Britain                                                                          
polychoric ChNeeds AdviceProf LessAvailable BadJob AlwaysAvailable ChAttention ///
PaKnow Activities PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys [pw=w2weight] if country==2 
display r(sum_w) // number of cases (with listwise deletion) used to generate the matrix
matrix r = r(R) //  store the polychoric correlation matrix
factormat r, n(628) pcf factor(4)
rotate 

*Estonia
polychoric ChNeeds AdviceProf LessAvailable BadJob AlwaysAvailable ChAttention ///
PaKnow Activities PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys [pw=w2weight] if country==1 
display r(sum_w) // number of cases (with listwise deletion) used to generate the matrix
matrix r = r(R) //  store the polychoric correlation matrix
factormat r, n(601) pcf factor(4)
rotate 

*Slovenia                                                                       
polychoric ChNeeds AdviceProf LessAvailable BadJob AlwaysAvailable ChAttention ///
PaKnow Activities PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys [pw=w2weight] if country==3 
display r(sum_w) // number of cases (with listwise deletion) used to generate the matrix
matrix r = r(R) //  store the polychoric correlation matrix
factormat r, n(455) pcf factor(4)
rotate 

*----------------------------------------------------------------------------------------------------------------------------------*

* b. Exploratory Factor Analysis (Polychoric) - 18 items, by country

**Great Britain**
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country==2 
display r(sum_w) 
matrix r = r(R) 
factormat r, pcf n(628)  
rotate 

screeplot

*Eigenvalues>1 - Varimax Rotation (6 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country==2 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(628) pcf factor(6)
rotate 

*Scatterplot - Varimax Rotation (5 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country==2 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(628) pcf factor(5)
rotate 

*Scatterplot - Varimax Rotation (4 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country==2 
display r(sum_w) 
matrix r = r(R) 
factormat r, n(628) pcf factor(4)
rotate 

**Estonia**
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country ==1
display r(sum_w) 
matrix r = r(R) 
factormat r, pcf n(601)  
rotate

screeplot

*Eigenvalues>1 - Varimax Rotation (6 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country ==1
display r(sum_w) 
matrix r = r(R) 
factormat r, n(601) pcf factor(6)
rotate 

*Scatterplot - Varimax Rotation (5 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country ==1
display r(sum_w) 
matrix r = r(R) 
factormat r, n(601) pcf factor(5)
rotate 

*Scatterplot - Varimax Rotation (4 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country ==1
display r(sum_w) 
matrix r = r(R) 
factormat r, n(601) pcf factor(4)
rotate 

**Slovenia**
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country==3
display r(sum_w) 
matrix r = r(R) 
factormat r, pcf n(455) 
rotate 

screeplot

*Eigenvalues>1 - Varimax Rotation (6 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country==3
display r(sum_w) 
matrix r = r(R) 
factormat r, n(455) pcf factor(6)
rotate 

*Scatterplot - Varimax Rotation (5 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country==3
display r(sum_w) 
matrix r = r(R) 
factormat r, n(455) pcf factor(5)
rotate 

*Scatterplot - Varimax Rotation (4 factors)
polychoric ChNeeds AdviceProf LessAvailable ChSuccess FamRoutine BadJob AlwaysAvailable ChMistakes ///
ChAttention PaKnow Activitie PaWorry ChTalents AwareExperts BasicNeeds PaLife LatestToys PaStress [pw=w2weight] if country==3
display r(sum_w) 
matrix r = r(R) 
factormat r, n(455) pcf factor(4)
rotate 

*-------------------------------------------------------------------------------------------------------------------------*

* c. Mean values and percent agreeing with each item by country + ANOVA

**Great Britain**

*Child-intensive
tab ChNeeds if country==2 [aw=w2weight]
mean ChNeeds if country==2 [aw=w2weight]
tab LessAvailable if country==2 [aw=w2weight]
mean LessAvailable if country==2 [aw=w2weight]
tab AlwaysAvailable if country==2 [aw=w2weight]
mean AlwaysAvailable if country==2 [aw=w2weight]
tab ChAttention if country==2 [aw=w2weight]
mean ChAttention if country==2 [aw=w2weight]
tab BasicNeeds if country==2 [aw=w2weight]
mean BasicNeeds if country==2 [aw=w2weight]
tab PaLife if country==2 [aw=w2weight]
mean PaLife if country==2 [aw=w2weight]

*Stimulation
tab Activities if country==2 [aw=w2weight]
mean Activities if country==2 [aw=w2weight]
tab PaWorry if country==2 [aw=w2weight]
mean PaWorry if country==2 [aw=w2weight]
tab ChTalents if country==2 [aw=w2weight]
mean ChTalents if country==2 [aw=w2weight]

*Responsibility
tab BadJob if country==2 [aw=w2weight]
mean BadJob if country==2 [aw=w2weight]
tab PaKnow if country==2 [aw=w2weight]
mean PaKnow if country==2 [aw=w2weight]
tab LatestToys if country==2 [aw=w2weight]
mean LatestToys if country==2 [aw=w2weight]

*Expert-guided
tab AdviceProf if country==2 [aw=w2weight]
mean AdviceProf if country==2 [aw=w2weight]
tab AwareExperts if country==2 [aw=w2weight]
mean AwareExperts if country==2 [aw=w2weight]

**Estonia**

*Child-intensive
tab ChNeeds if country==1 [aw=w2weight]
mean ChNeeds if country==1 [aw=w2weight]
tab LessAvailable if country==1 [aw=w2weight]
mean LessAvailable if country==1 [aw=w2weight]
tab AlwaysAvailable if country==1 [aw=w2weight]
mean AlwaysAvailable if country==1 [aw=w2weight]
tab ChAttention if country==1 [aw=w2weight]
mean ChAttention if country==1 [aw=w2weight]
tab BasicNeeds if country==1 [aw=w2weight]
mean BasicNeeds if country==1 [aw=w2weight]
tab PaLife if country==1 [aw=w2weight]
mean PaLife if country==1 [aw=w2weight]

*Stimulation
tab Activities if country==1 [aw=w2weight]
mean Activities if country==1 [aw=w2weight]
tab PaWorry if country==1 [aw=w2weight]
mean PaWorry if country==1 [aw=w2weight]
tab ChTalents if country==1 [aw=w2weight]
mean ChTalents if country==1 [aw=w2weight]

*Responsibility
tab BadJob if country==1 [aw=w2weight]
mean BadJob if country==1 [aw=w2weight]
tab PaKnow if country==1 [aw=w2weight]
mean PaKnow if country==1 [aw=w2weight]
tab LatestToys if country==1 [aw=w2weight]
mean LatestToys if country==1 [aw=w2weight]

*Expert-guided
tab AdviceProf if country==1 [aw=w2weight]
mean AdviceProf if country==1 [aw=w2weight]
tab AwareExperts if country==1 [aw=w2weight]
mean AwareExperts if country==1 [aw=w2weight]

**Slovenia**

*Child-intensive
tab ChNeeds if country==3 [aw=w2weight]
mean ChNeeds if country==3 [aw=w2weight]
tab LessAvailable if country==3 [aw=w2weight]
mean LessAvailable if country==3 [aw=w2weight]
tab AlwaysAvailable if country==3 [aw=w2weight]
mean AlwaysAvailable if country==3 [aw=w2weight]
tab ChAttention if country==3 [aw=w2weight]
mean ChAttention if country==3 [aw=w2weight]
tab BasicNeeds if country==3 [aw=w2weight]
mean BasicNeeds if country==3 [aw=w2weight]
tab PaLife if country==3 [aw=w2weight]
mean PaLife if country==3 [aw=w2weight]

*Stimulation
tab Activities if country==3 [aw=w2weight]
mean Activities if country==3 [aw=w2weight]
tab PaWorry if country==3 [aw=w2weight]
mean PaWorry if country==3 [aw=w2weight]
tab ChTalents if country==3 [aw=w2weight]
mean ChTalents if country==3 [aw=w2weight]

*Responsibility
tab BadJob if country==3 [aw=w2weight]
mean BadJob if country==3 [aw=w2weight]
tab PaKnow if country==3 [aw=w2weight]
mean PaKnow if country==3 [aw=w2weight]
tab LatestToys if country==3 [aw=w2weight]
mean LatestToys if country==3 [aw=w2weight]

*Expert-guided
tab AdviceProf if country==3 [aw=w2weight]
mean AdviceProf if country==3 [aw=w2weight]
tab AwareExperts if country==3 [aw=w2weight]
mean AwareExperts if country==3 [aw=w2weight]

*ANOVA to test whether values are significantly different than those in GB (Supplementary table: table 4)

*Child-intensive
oneway ChNeeds country, tab
pwmean ChNeeds, over(country) mcompare(tukey) effect
oneway LessAvailable country, tab
pwmean LessAvailable, over(country) mcompare(tukey) effect
oneway AlwaysAvailable country, tab
pwmean AlwaysAvailable, over(country) mcompare(tukey) effect
oneway ChAttention country, tab
pwmean ChAttention, over(country) mcompare(tukey) effect
oneway BasicNeeds country, tab
pwmean BasicNeeds, over(country) mcompare(tukey) effect
oneway PaLife country, tab
pwmean PaLife, over(country) mcompare(tukey) effect

*Stimulation
oneway Activities country, tab
pwmean Activities, over(country) mcompare(tukey) effect
oneway PaWorry country, tab
pwmean PaWorry, over(country) mcompare(tukey) effect
oneway ChTalents country, tab
pwmean ChTalents, over(country) mcompare(tukey) effect

*Responsibility
oneway BadJob country, tab
pwmean BadJob, over(country) mcompare(tukey) effect
oneway PaKnow country, tab
pwmean PaKnow, over(country) mcompare(tukey) effect
oneway LatestToys country, tab
pwmean LatestToys, over(country) mcompare(tukey) effect

*Expert-guided
oneway AdviceProf country, tab
pwmean AdviceProf, over(country) mcompare(tukey) effect
oneway AwareExperts country, tab
pwmean AwareExperts, over(country) mcompare(tukey) effect

*-------------------------------------------------------------------------------------------------------------------------*

* d. Mean value of the items for each educational level 

sum ChNeeds LessAvailable AlwaysAvailable ChAttention BasicNeeds PaLife Activities PaWorry ChTalents ///
BadJob LatestToys PaKnow AdviceProf AwareExperts [aw=w2weight] if edul==1

sum ChNeeds LessAvailable AlwaysAvailable ChAttention BasicNeeds PaLife Activities PaWorry ChTalents ///
BadJob LatestToys PaKnow AdviceProf AwareExperts [aw=w2weight] if edul==2

sum ChNeeds LessAvailable AlwaysAvailable ChAttention BasicNeeds PaLife Activities PaWorry ChTalents ///
BadJob LatestToys PaKnow AdviceProf AwareExperts [aw=w2weight] if edul==3

*-------------------------------------------------------------------------------------------------------------------------*

* e. Subscale mean values by country 

*Child intensive
bysort country: sum ipa_childint                      // mean using factor loadings
bysort country: sum ipa1                              // mean using items

*Stimulation
bysort country: sum ipa_stimulation                   // mean using factor loadings
bysort country: sum ipa2                              // mean using items

*Parental Responsibility 
bysort country: sum ipa_parentresp                    // mean using factor loadings
bysort country: sum ipa3                              // mean using items

*Expert-guidance
bysort country: sum ipa_expert                        // mean using factor loadings
bysort country: sum ipa4                              // mean using items

*-------------------------------------------------------------------------------------------------------------------------*
